@@ -31,10 +31,10 @@ class Command(BaseCommand):
                           person.talks.filter(status=ACCEPTED)]
                 if not titles:
                     continue
-            row = [x.encode("utf-8")
+            row = [x
                    for x in (person.userprofile.display_name(), person.email,
-                   person.userprofile.contact_number or 'NO CONTACT INFO',
-                   ';'.join(titles))]
+                             person.userprofile.contact_number or 'NO CONTACT INFO',
+                             ';'.join(titles))]
             csv_file.writerow(row)
 
     def handle(self, *args, **options):
