@@ -3,7 +3,8 @@ from rest_framework import routers
 
 
 from wafer.schedule.views import (
-    CurrentView, ScheduleView, ScheduleItemViewSet, ScheduleXmlView, VenueView)
+    CurrentView, ScheduleView, ScheduleItemViewSet, ScheduleXmlView,
+    VenueView, ICalView)
 
 router = routers.DefaultRouter()
 router.register(r'scheduleitems', ScheduleItemViewSet)
@@ -14,5 +15,6 @@ urlpatterns = [
     url(r'^current/$', CurrentView.as_view(), name='wafer_current'),
     url(r'^pentabarf\.xml$', ScheduleXmlView.as_view(),
         name='wafer_pentabarf_xml'),
+    url(r'^schedule\.ics$', ICalView.as_view(), name="schedule.ics"),
     url(r'^api/', include(router.urls)),
 ]
