@@ -127,8 +127,13 @@
 
         e.target.classList.remove('success');
         e.target.classList.remove('info');
-        var typeClass = scheduleItemType === 'talk' ? 'success' : 'info';
+        var typeClass = scheduleItemType === 'talk' ? 'table-success' : 'table-info';
         e.target.classList.add(typeClass);
+        if (scheduleItemType == 'talk') {
+            e.target.setAttribute('data-talk-id', talkId);
+            var unassigned = document.getElementById("talk" + talkId);
+            unassigned.hidden = true;
+        }
 
         var ajaxData = {
             talk: talkId,
@@ -170,9 +175,10 @@
 
         scheduleItemCell.removeAttribute('id');
         scheduleItemCell.classList.remove('draggable');
-        scheduleItemCell.classList.remove('info');
-        scheduleItemCell.classList.remove('success');
+        scheduleItemCell.classList.remove('table-info');
+        scheduleItemCell.classList.remove('table-success');
         scheduleItemCell.removeAttribute('data-scheduleitem-id');
+        var talkId = scheduleItemCell.getAttribute('data-talk-id');
         scheduleItemCell.removeAttribute('data-talk-id');
         scheduleItemCell.removeAttribute('data-page-id');
         scheduleItemCell.removeAttribute('data-type');
@@ -181,6 +187,11 @@
         closeButton.classList.add('hide');
         scheduleItemCell.innerHTML = '';
 
+        if (talkId) {
+            var unassigned = document.getElementById('talk' + talkId);
+            unassigned.hidden = false;
+        }
+
         $.ajax(
             {
                 type: 'DELETE',
