@@ -2,32 +2,16 @@
 
 import mock
 
-from django.contrib.auth import get_user_model
-from django.contrib.auth.models import Permission
 from django.test import Client, TestCase
 from django.urls import reverse
 
 from wafer.tests.api_utils import SortedResultsClient
+from wafer.tests.utils import create_user
 from wafer.talks.models import (
     Talk, TalkUrl, ACCEPTED, REJECTED, SUBMITTED, UNDER_CONSIDERATION,
     CANCELLED, PROVISIONAL)
 
 
-def create_user(username, superuser=False, perms=()):
-    if superuser:
-        create = get_user_model().objects.create_superuser
-    else:
-        create = get_user_model().objects.create_user
-    user = create(
-        username, '%s@example.com' % username, '%s_password' % username)
-    for codename in perms:
-        perm = Permission.objects.get(codename=codename)
-        user.user_permissions.add(perm)
-    if perms:
-        user = get_user_model().objects.get(pk=user.pk)
-    return user
-
-
 def create_talk(title, status, username):
     user = create_user(username)
     talk = Talk.objects.create(
@@ -512,7 +496,7 @@ class TalkViewSetPermissionTests(TestCase):
         self.assertEqual(response.status_code, 404)
 
     def test_super_user_gets_everything(self):
-        create_user('super', True)
+        create_user('super', superuser=True)
         self.client.login(username='super', password='super_password')
         response = self.client.get('/talks/api/talks/')
         self.assertEqual(response.data['count'], 3)
@@ -565,7 +549,7 @@ class TalkViewSetPermissionTests(TestCase):
 class TalkViewSetTests(TestCase):
 
     def setUp(self):
-        create_user('super', True)
+        create_user('super', superuser=True)
         self.client = SortedResultsClient(sort_key="title")
         self.client.login(username='super', password='super_password')
 
@@ -573,7 +557,7 @@ class TalkViewSetTests(TestCase):
         def mk_url(talk_url):
             return {
                 'id': talk_url.id, 'description': talk_url.description,
-                'url': talk_url.url,
+                'url': talk_url.url, 'public': talk_url.public,
             }
         return {
             'talk_id': talk.talk_id, 'talk_type': talk.talk_type,
@@ -582,7 +566,7 @@ class TalkViewSetTests(TestCase):
             'corresponding_author': talk.corresponding_author.id,
             'authors': [talk.corresponding_author.id],
             'kv': [],
-            'urls': [mk_url(url) for url in talk.urls.all()]
+            'urls': [mk_url(url) for url in talk.urls.all() if url.public]
         }
 
     def test_list_talks(self):
@@ -594,6 +578,17 @@ class TalkViewSetTests(TestCase):
         ])
 
     def test_retrieve_talk(self):
+        talk = create_talk("Talk A", ACCEPTED, "author_a")
+        talk.abstract = "Abstract Talk A"
+        talk.save()
+        TalkUrl.objects.create(
+            talk=talk, url="http://example.com/", description="video",
+            public=True)
+        response = self.client.get(
+            '/talks/api/talks/%d/' % talk.talk_id)
+        self.assertEqual(response.data, self.mk_result(talk))
+
+    def test_retrieve_talk_with_private_url(self):
         talk = create_talk("Talk A", ACCEPTED, "author_a")
         talk.abstract = "Abstract Talk A"
         talk.save()
@@ -685,7 +680,7 @@ class TalkUrlsViewSetPermissionTests(TestCase):
         self.assert_missing_talk_urls_code(403)
 
     def test_super_user_gets_all_talk_urls(self):
-        create_user('super', True)
+        create_user('super', superuser=True)
         self.client.login(username='super', password='super_password')
         self.assert_urls_accessible(self.talk_a)
         self.assert_urls_accessible(self.talk_s)
@@ -696,14 +691,14 @@ class TalkUrlsViewSetPermissionTests(TestCase):
 class TalkUrlsViewSetTests(TestCase):
 
     def setUp(self):
-        create_user('super', True)
+        create_user('super', superuser=True)
         self.client = SortedResultsClient(sort_key="url")
         self.client.login(username='super', password='super_password')
 
     def mk_result(self, talk_url):
         return {
             'id': talk_url.id, 'description': talk_url.description,
-            'url': talk_url.url,
+            'url': talk_url.url, 'public': talk_url.public,
         }
 
     def test_list_talk_urls(self):
@@ -717,6 +712,16 @@ class TalkUrlsViewSetTests(TestCase):
             self.mk_result(url_a), self.mk_result(url_b),
         ])
 
+    def test_list_talk_urls_nested_filtering(self):
+        talk_a = create_talk("Talk", ACCEPTED, "author")
+        talk_b = create_talk("Talk 2", ACCEPTED, "author 2")
+        url_a = TalkUrl.objects.create(
+            talk=talk_a, url="http://a.example.com/", description="video")
+        url_b = TalkUrl.objects.create(
+            talk=talk_b, url="http://b.example.com/", description="slides")
+        response = self.client.get('/talks/api/talks/%d/urls/' % talk_a.talk_id)
+        self.assertEqual(response.data['results'], [self.mk_result(url_a)])
+
     def test_retrieve_talk_url(self):
         talk = create_talk("Talk A", ACCEPTED, "author_a")
         url = TalkUrl.objects.create(
@@ -731,6 +736,7 @@ class TalkUrlsViewSetTests(TestCase):
             '/talks/api/talks/%d/urls/' % talk.talk_id, data={
                 'description': u'slides',
                 'url': u'http://www.example.com/video',
+                'public': True,
             }, format="json")
         [talk_url] = talk.urls.all()
         self.assertEqual(response.data, self.mk_result(talk_url))
@@ -745,6 +751,7 @@ class TalkUrlsViewSetTests(TestCase):
             '/talks/api/talks/%d/urls/%d/' % (talk.talk_id, url.id), data={
                 'description': u'slides',
                 'url': u'http://www.example.com/video',
+                'public': True,
             }, format="json")
         [talk_url] = talk.urls.all()
         self.assertEqual(response.data, self.mk_result(talk_url))
